#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-CJKDuS8fq9PBqGXaYa3dlm
key:                  dlist-instances-0.1.1.1-CJKDuS8fq9PBqGXaYa3dlm
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  3e19bf14dee973510e9edb0c7697764b
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dlist-instances-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dlist-instances
hs-libraries:         HSdlist-instances-0.1.1.1-CJKDuS8fq9PBqGXaYa3dlm
depends:              base-4.18.2.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

